#!/usr/local/bin/perl

use utf8;
use Modern::Perl '2012';
#use Data::Dumper;
use Data::Dumper::AutoEncode;
use HTML::TableExtract;
use IO::All;
use JSON::MaybeXS qw(:legacy);
use Text::Trim;
use YAML::Syck;

sub _strip {
    my ($html) = @_;
    return "" unless $html;

    $html =~ s{<span style="display:none".*?</span>}{};

    trim( HTML::TableExtract::StripHTML->new->strip($html) );
}

binmode STDOUT, ":utf8";

for my $in ( grep /html$/, io("wikipedia")->all_files ) {
    my $html_string = $in->utf8->all;

    my $te = HTML::TableExtract->new(
        headers   => [qw(語族 言語 原語名 639-1 639-2/T 639-2/B 639-3 639-6 備考)],
        keep_html => 1,
    );
    $te->parse($html_string);

    my @items;
    {
        my ($table) = $te->tables;
        for my $row ($table->rows) {
            $row = [ map _strip($_), @$row ];
            my %item;
            @item{qw(language_family iso_language_name native_name 639_1 639_2_t 639_2_b 639_3 639_6 notes)} = @$row;
            push @items, \%item;
        }
    }

    io->catfile( 'share', $in->filename =~ s/html$/json/r )->print( encode_json \@items );
    io->catfile( 'share', $in->filename =~ s/html$/yml/r  )->print( Dump \@items );
    local $Data::Dumper::Sortkeys = 1;
    io->catfile( 'share', $in->filename =~ s/html$/pl/r  )->print( eDumper \@items );
    #local $Data::Dumper::Indent   = 0;
    local $Data::Dumper::Terse    = 1;
    io->catfile( 'share', $in->filename =~ s/html$/terse/r  )->print( eDumper \@items );
}
