use utf8;
use strict;
use warnings;
use Test::More;
use List::Util qw(first);

use_ok 'ISO639::Japanese';

{
    my $codes = ISO639::Japanese->codes_arrayref;
    my $ja    = first { $_->{native_name} eq '日本語' } @$codes;
    ok $ja;
    is $ja->{language_family}, '日本語族', 'japanese';
}

{
    my $ja = ISO639::Japanese->find( native_name => '日本語' );
    ok $ja;
    is $ja->{language_family}, '日本語族', 'japanese';
}

{
    my $not_single = ISO639::Japanese->find( language_family => 'ドラヴィダ語族' );
    ok !$not_single;
}

{
    my @multiple = ISO639::Japanese->search( language_family => 'ドラヴィダ語族' );
    is @multiple, 4;
}

{
    my @codes = ISO639::Japanese->index_keys('639_1');
    ok @codes > 100;
    ok grep $_ eq 'ja', @codes;
}

{
    my $cn = ISO639::Japanese->find( iso_language_name => '中国語' );
    ok $cn;
    is $cn->{native_name}, '中文,汉语,漢語', 'native_name commas are not parsed and remain.'
}

done_testing;
